pub enum CastSizedExact {}Expand description
A pointer cast which preserves the set of referent bytes of a statically-sized referent.
Safety
The implementation of Project uses a compile-time assertion to
guarantee that Dst has the same size as Src. Thus, CastSizedExact
has a sound implementation of Project for all Src and Dst – the
caller may pass any Src and Dst without being responsible for
soundness.